@@ -97,7 +97,7 @@ find_statistic <- function(x, ...) {
     "ivreg", "ivFixed", "iv_robust", "ivprobit",
     "lm", "lm_robust", "lm.beta", "lme", "lmerMod", "lmerModLmerTest",
     "lmodel2", "lmRob", "lmrob", "lqm", "lqmm",
-    "maxLik", "mixed", "mhurdle", "mlm", "multinom", "marginaleffects", "marginaleffects.summary",
+    "maxLik", "mixed", "mhurdle", "mlm", "multinom",
     "nlmerMod", "nlrq", "nls",
     "ols", "orcutt",
     "pb1", "pb2", "polr",
@@ -117,15 +117,16 @@ find_statistic <- function(x, ...) {
     "boot_test_mediation", "bracl", "brglm", "brglmFit", "brmultinom", "btergm",
     "cglm", "cph", "clm", "clm2", "clmm", "clmm2", "clogit", "coxme", "coxph",
     "coxr", "crch", "crr",
-    "DirichletRegModel",
+    "deltaMethod", "DirichletRegModel",
     "ergm",
     "feglm", "flexsurvreg",
     "gee", "glimML", "glmm", "glmmadmb", "glmmFit", "glmmLasso", "glmmTMB",
     "glmx", "gmnl",
     "hurdle",
     "lavaan", "loggammacenslmrob", "logitmfx", "logitor", "LORgee", "lrm",
-    "margins", "metaplus", "mixor", "MixMod", "mjoint", "mle", "mle2", "mlogit",
-    "mclogit", "mmclogit", "mvmeta", "mvord",
+    "margins", "marginaleffects", "marginaleffects.summary", "metaplus", "mixor",
+    "MixMod", "mjoint", "mle", "mle2", "mlogit", "mclogit", "mmclogit", "mvmeta",
+    "mvord",
     "negbin", "negbinmfx", "negbinirr", "nlreg",
     "objectiveML", "orm",
     "poissonmfx", "poissonirr", "psm", "probitmfx", "pgmm",
@@ -151,6 +152,7 @@ find_statistic <- function(x, ...) {
   # chi-squared value objects ------------------------------------------------
 
   chi.mods <- c(
+    "anova.rms",
     "coxph.penal",
     "epi.2by2",
     "geeglm",
