@@ -303,6 +303,37 @@ get_df.selection <- function(x, type = "residual", ...) {
 }
 
 
+#' @export
+get_df.lmerMod <- function(x, type = "residual", ...) {
+  dots <- list(...)
+  type <- match.arg(tolower(type), choices = c("residual", "model", "analytical", "satterthwaite", "kenward", "kenward-roger"))
+  # fix name for lmerTest
+  if (type == "kenward") {
+    type <- "kenward-roger"
+  }
+  if (type %in% c("satterthwaite", "kenward-roger")) {
+    check_if_installed("lmerTest")
+    type <- tools::toTitleCase(type) # lmerTest wants title case
+    if (!inherits(dots$data, "data.frame")) {
+      stop("The `data` argument should be a data.frame.")
+    }
+    mm <- get_modelmatrix(x, data = dots$data)
+    out <- sapply(
+      seq_len(nrow(mm)), function(i)
+      suppressMessages(
+        lmerTest::contestMD(x, mm[i, , drop = FALSE], ddf = type)[["DenDF"]]
+      )
+    )
+    return(out)
+  } else {
+    get_df.default(x, type = type, ...)
+  }
+}
+
+#' @export
+get_df.lmerModTest <- get_df.lmerMod
+
+
 #' @export
 get_df.logitor <- function(x, type = "residual", ...) {
   type <- match.arg(tolower(type), choices = c("residual", "model"))
