@@ -8,18 +8,27 @@ get_predicted.stanreg <- function(x,
                                   data = NULL,
                                   predict = "expectation",
                                   iterations = NULL,
+                                  ci = 0.95,
+                                  ci_method = NULL,
                                   include_random = "default",
                                   include_smooth = TRUE,
                                   verbose = TRUE,
                                   ...) {
   check_if_installed("rstantools", minimum_version = "2.1.0")
 
+  if (is.null(ci_method)) ci_method <- "quantile"
+  ci_method <- match.arg(
+    tolower(ci_method),
+    choices = c("quantile", "eti", "hdi")
+  )
+
   args <- .get_predicted_args(
     x,
     data = data,
     predict = predict,
     include_random = include_random,
     include_smooth = include_smooth,
+    ci = ci,
     verbose = verbose,
     ...
   )
@@ -79,6 +88,8 @@ get_predicted.stanreg <- function(x,
     predictions = predictions,
     data = args$data,
     ci_type = args$ci_type,
+    ci = ci,
+    ci_method = ci_method,
     ...
   )
 
