@@ -1,41 +1,12 @@
+#' Confidence intervals around predicted values
+#'
 #' @inheritParams get_predicted
 #' @param predictions A vector of predicted values (as obtained by
 #'   `stats::fitted()`, `stats::predict()` or
 #'   [get_predicted()]).
-#' @param ci The interval level (default `0.95`, i.e., `95%` CI).
-#' @param ci_type Can be `"prediction"` or `"confidence"`. Prediction
-#'   intervals show the range that likely contains the value of a new
-#'   observation (in what range it would fall), whereas confidence intervals
-#'   reflect the uncertainty around the estimated parameters (and gives the
-#'   range of the link; for instance of the regression line in a linear
-#'   regressions). Prediction intervals account for both the uncertainty in the
-#'   model's parameters, plus the random variation of the individual values.
-#'   Thus, prediction intervals are always wider than confidence intervals.
-#'   Moreover, prediction intervals will not necessarily become narrower as the
-#'   sample size increases (as they do not reflect only the quality of the fit).
-#'   This applies mostly for "simple" linear models (like `lm`), as for
-#'   other models (e.g., `glm`), prediction intervals are somewhat useless
-#'   (for instance, for a binomial model for which the dependent variable is a
-#'   vector of 1s and 0s, the prediction interval is... `[0, 1]`).
 #' @param se Numeric vector of standard error of predicted values. If `NULL`,
 #'   standard errors are calculated based on the variance-covariance matrix.
-#' @param vcov Variance-covariance matrix used to compute uncertainty estimates (e.g., for robust standard errors). This argument accepts a covariance matrix, a function which returns a covariance matrix, or a string which identifies the function to be used to compute the covariance matrix.
-#'  * A covariance matrix
-#'  * A function which returns a covariance matrix (e.g., `stats::vcov()`)
-#'  * A string which indicates the kind of uncertainty estimates to return.
-#'    - Heteroskedasticity-consistent: `"vcovHC"`, `"HC"`, `"HC0"`, `"HC1"`, `"HC2"`, `"HC3"`, `"HC4"`, `"HC4m"`, `"HC5"`. See `?sandwich::vcovHC`
-#'    - Cluster-robust: `"vcovCR"`, `"CR0"`, `"CR1"`, `"CR1p"`, `"CR1S"`, `"CR2"`, `"CR3"`. See `?clubSandwich::vcovCR()`
-#'    - Bootstrap: `"vcovBS"`, `"xy"`, `"residual"`, `"wild"`, `"mammen"`, `"webb"`. See `?sandwich::vcovBS`
-#'    - Other `sandwich` package functions: `"vcovHAC"`, `"vcovPC"`, `"vcovCL"`, `"vcovPL"`.
-#' @param vcov_args List of arguments to be passed to the function identified by
-#'   the `vcov` argument. This function is typically supplied by the **sandwich**
-#'   or **clubSandwich** packages. Please refer to their documentation (e.g.,
-#'   `?sandwich::vcovHAC`) to see the list of available arguments.
-#' @param dispersion_method,ci_method These arguments are only used in
-#'   the context of bootstrapped and Bayesian models. Possible values are
-#'   `dispersion_method = c("sd", "mad")` and
-#'   `ci_method = c("quantile", "hdi", "eti")`. For the latter, the
-#'   **bayestestR** package is required.
+#' @inheritParams get_predicted
 #'
 #' @examples
 #' # Confidence Intervals for Model Predictions
@@ -83,7 +54,6 @@
 #' head(ci_vals)
 #' ci_vals <- get_predicted_ci(x, predictions, ci_type = "confidence")
 #' head(ci_vals)
-#' @rdname get_predicted
 #' @export
 get_predicted_ci <- function(x, predictions = NULL, ...) {
   UseMethod("get_predicted_ci")
@@ -94,7 +64,7 @@ get_predicted_ci <- function(x, predictions = NULL, ...) {
 
 # General method ----------------------------------------------------------
 
-#' @rdname get_predicted
+#' @rdname get_predicted_ci
 #' @export
 get_predicted_ci.default <- function(x,
                                      predictions = NULL,
@@ -102,21 +72,31 @@ get_predicted_ci.default <- function(x,
                                      se = NULL,
                                      ci = 0.95,
                                      ci_type = "confidence",
-                                     ci_method = "quantile",
+                                     ci_method = NULL,
                                      dispersion_method = "sd",
                                      vcov = NULL,
                                      vcov_args = NULL,
                                      ...) {
+
   # sanity check, if CI should be skipped
   if (is.null(ci)) {
     return(ci)
   }
 
+  # default ci_method depends on the type of predictions and model
+  if (is.null(ci_method)) {
+    if ("iterations" %in% names(attributes(predictions))) {
+      ci_method <- "quantile"
+    } else {
+      ci_method <- "normal"
+    }
+  }
+
   # If draws are present (bootstrapped or Bayesian)
   if ("iterations" %in% names(attributes(predictions))) {
     iter <- attributes(predictions)$iteration
     se <- .get_predicted_se_from_iter(iter = iter, dispersion_method)
-    out <- .get_predicted_ci_from_iter(iter = iter, ci = ci, ci_method)
+    out <- .get_predicted_ci_from_iter(iter = iter, ci = ci, ci_method = ci_method)
     out <- cbind(se, out)
     # outcome is multinomial/ordinal/cumulative
     if (inherits(predictions, "data.frame") &&
@@ -138,6 +118,7 @@ get_predicted_ci.default <- function(x,
       ci_type = ci_type,
       vcov = vcov,
       vcov_args = vcov_args,
+      ci_method = ci_method,
       ...
     )
     ci_function <- .get_predicted_se_to_ci
@@ -150,11 +131,11 @@ get_predicted_ci.default <- function(x,
   if (is.null(ci)) {
     out <- data.frame(SE = se)
   } else if (length(ci) == 1) {
-    out <- ci_function(x, predictions, ci = ci, se = se)
+    out <- ci_function(x, predictions, ci = ci, se = se, ci_method = ci_method, data = data, ...)
   } else {
     out <- data.frame(SE = se)
     for (ci_val in ci) {
-      temp <- ci_function(x, predictions, ci = ci_val, se = se)
+      temp <- ci_function(x, predictions, ci = ci_val, se = se, ci_method = ci_method, data = data, ...)
       temp$SE <- NULL
       names(temp) <- paste0(names(temp), "_", ci_val)
       out <- cbind(out, temp)
@@ -178,11 +159,15 @@ get_predicted_ci.mlm <- function(x, ...) {
                                     predictions = NULL,
                                     se = NULL,
                                     ci = 0.95,
+                                    ci_method = "quantile",
+                                    data = NULL,
                                     ...) {
 
   # TODO: Prediction interval for binomial: https://fromthebottomoftheheap.net/2017/05/01/glm-prediction-intervals-i/
   # TODO: Prediction interval for poisson: https://fromthebottomoftheheap.net/2017/05/01/glm-prediction-intervals-ii/
 
+  dots <- list(...)
+
   # Sanity checks
   if (!is.null(se)) {
     se <- as.numeric(se)
@@ -195,7 +180,12 @@ get_predicted_ci.mlm <- function(x, ...) {
     return(data.frame(CI_low = predictions, CI_high = predictions))
   } # Same as predicted
 
-  dof <- get_df(x, type = "residual")
+  # data is required for satterthwaite
+  if (isTRUE(ci_method %in% c("satterthwaite", "kenward", "kenward-roger"))) {
+    dof <- get_df(x, type = ci_method, data = data)
+  } else {
+    dof <- get_df(x)
+  }
 
   # Return NA
   if (is.null(se)) {
@@ -204,7 +194,8 @@ get_predicted_ci.mlm <- function(x, ...) {
     # Get CI
     # TODO: Does this cover all the model families?
   } else {
-    if (is.null(dof) || is.infinite(dof) || find_statistic(x) == "z-statistic") {
+    # use `all()` because `dof` can be a vector with satterthwaite
+    if (is.null(dof) || all(is.infinite(dof)) || find_statistic(x) == "z-statistic") {
       crit_val <- stats::qnorm(p = (1 + ci) / 2)
     } else {
       crit_val <- stats::qt(p = (1 + ci) / 2, df = dof)
@@ -334,7 +325,11 @@ get_predicted_ci.mlm <- function(x, ...) {
 .get_predicted_ci_from_iter <- function(iter, ci = 0.95, ci_method = "quantile") {
 
   # Interval
-  ci_method <- match.arg(tolower(ci_method), c("quantile", "hdi", "eti"))
+  ci_method <- match.arg(
+    tolower(ci_method),
+    c("quantile", "hdi", "eti", "satterthwaite", "normal")
+  )
+
   if (ci_method == "quantile") {
     out <- data.frame(Parameter = 1:nrow(iter))
     for (i in ci) {
