@@ -21,13 +21,27 @@
 #'   applies to models of class `mixor`.
 #' @param complete Logical, if `TRUE`, for `aov`, returns the full
 #'   variance-covariance matrix.
-#' @param robust Logical, if `TRUE`, returns a robust variance-covariance matrix
-#'   using sandwich estimation.
+#' @param vcov Variance-covariance matrix used to compute uncertainty estimates (e.g., for robust standard errors). This argument accepts a covariance matrix, a function which returns a covariance matrix, or a string which identifies the function to be used to compute the covariance matrix.
+#'  * A covariance matrix
+#'  * A function which returns a covariance matrix (e.g., `stats::vcov()`)
+#'  * A string which indicates the kind of uncertainty estimates to return.
+#'    - Heteroskedasticity-consistent: `"vcovHC"`, `"HC"`, `"HC0"`, `"HC1"`, `"HC2"`, `"HC3"`, `"HC4"`, `"HC4m"`, `"HC5"`. See `?sandwich::vcovHC`
+#'    - Cluster-robust: `"vcovCR"`, `"CR0"`, `"CR1"`, `"CR1p"`, `"CR1S"`, `"CR2"`, `"CR3"`. See `?clubSandwich::vcovCR()`
+#'    - Bootstrap: `"vcovBS"`, `"xy"`, `"residual"`, `"wild"`, `"mammen"`, `"webb"`. See `?sandwich::vcovBS`
+#'    - Other `sandwich` package functions: `"vcovHAC"`, `"vcovPC"`, `"vcovCL"`, `"vcovPL"`.
+#' @param vcov_args List of arguments to be passed to the function identified by
+#'   the `vcov` argument. This function is typically supplied by the **sandwich**
+#'   or **clubSandwich** packages. Please refer to their documentation (e.g.,
+#'   `?sandwich::vcovHAC`) to see the list of available arguments.
+
 #' @param verbose Toggle warnings.
 #' @param ... Currently not used.
 #'
 #' @note `get_varcov()` tries to return the nearest positive definite matrix
-#'   in case of a negative variance-covariance matrix.
+#'   in case of negative eigenvalues of the variance-covariance matrix. This
+#'   ensures that it is still possible, for instance, to calculate standard
+#'   errors of model parameters. A message is shown when the matrix is negative
+#'   definite and a corrected matrix is returned.
 #'
 #' @return The variance-covariance matrix, as `matrix`-object.
 #'
@@ -35,6 +49,25 @@
 #' data(mtcars)
 #' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
 #' get_varcov(m)
+#'
+#' # vcov of zero-inflation component from hurdle-model
+#' if (require("pscl")) {
+#'   data("bioChemists", package = "pscl")
+#'   mod <- hurdle(art ~ phd + fem | ment, data = bioChemists, dist = "negbin")
+#'   get_varcov(mod, component = "zero_inflated")
+#' }
+#'
+#' # robust vcov of, count component from hurdle-model
+#' if (require("pscl") && require("sandwich")) {
+#'   data("bioChemists", package = "pscl")
+#'   mod <- hurdle(art ~ phd + fem | ment, data = bioChemists, dist = "negbin")
+#'   get_varcov(
+#'     mod,
+#'     component = "conditional",
+#'     vcov = "BS",
+#'     vcov_args = list(R = 50)
+#'   )
+#' }
 #' @export
 get_varcov <- function(x, ...) {
   UseMethod("get_varcov")
@@ -46,9 +79,26 @@ get_varcov <- function(x, ...) {
 
 #' @rdname get_varcov
 #' @export
-get_varcov.default <- function(x, verbose = TRUE, ...) {
-  vc <- suppressWarnings(stats::vcov(x))
-  .process_vcov(vc, verbose)
+get_varcov.default <- function(x,
+                               verbose = TRUE,
+                               vcov = NULL,
+                               vcov_args = NULL,
+                               ...) {
+
+  .check_get_varcov_dots(x, ...)
+  # process vcov-argument
+  vcov <- .check_vcov_args(x, vcov = vcov, verbose = verbose, ...)
+
+  if (is.null(vcov)) {
+    vc <- suppressWarnings(stats::vcov(x))
+  } else {
+    vc <- .get_varcov_sandwich(x,
+                               vcov_fun = vcov,
+                               vcov_args = vcov_args,
+                               verbose = FALSE,
+                               ...)
+  }
+  .process_vcov(vc, verbose, ...)
 }
 
 #' @export
@@ -57,16 +107,28 @@ get_varcov.maxLik <- get_varcov.default
 #' @export
 get_varcov.HLfit <- get_varcov.default
 
+#' @export
+get_varcov.geeglm <- get_varcov.default
+
+
 
 # mlm ---------------------------------------------
 
 #' @export
-get_varcov.mlm <- function(x, ...) {
+get_varcov.mlm <- function(x,
+                           vcov = NULL,
+                           vcov_args = NULL,
+                           ...) {
+  .check_get_varcov_dots(x, ...)
   if (!is.null(x$weights)) {
+    if (!is.null(vcov)) {
+      stop(format_message("The `vcov` argument is not supported with",
+                          "weights in a `mlm` model."), call. = FALSE)
+    }
     s <- summary(x)[[1L]]
     .get_weighted_varcov(x, s$cov.unscaled)
   } else {
-    get_varcov.default(x)
+    get_varcov.default(x, vcov = vcov, vcov_args = vcov_args, ...)
   }
 }
 
@@ -81,6 +143,8 @@ get_varcov.betareg <- function(x,
                                component = c("conditional", "precision", "all"),
                                verbose = TRUE,
                                ...) {
+
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
 
   vc <- switch(component,
@@ -88,16 +152,16 @@ get_varcov.betareg <- function(x,
     "precision" = stats::vcov(object = x, model = "precision"),
     stats::vcov(object = x)
   )
-  .process_vcov(vc, verbose)
+  .process_vcov(vc, verbose, ...)
 }
 
 
-#' @rdname get_varcov
 #' @export
 get_varcov.DirichletRegModel <- function(x,
                                          component = c("conditional", "precision", "all"),
                                          verbose = TRUE,
                                          ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
   if (x$parametrization == "common") {
     vc <- stats::vcov(x)
@@ -114,7 +178,7 @@ get_varcov.DirichletRegModel <- function(x,
       vc <- stats::vcov(x)
     }
   }
-  .process_vcov(vc, verbose)
+  .process_vcov(vc, verbose, ...)
 }
 
 
@@ -123,6 +187,7 @@ get_varcov.DirichletRegModel <- function(x,
 get_varcov.clm2 <- function(x,
                             component = c("all", "conditional", "scale"),
                             ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
 
   n_intercepts <- length(x$xi)
@@ -131,7 +196,7 @@ get_varcov.clm2 <- function(x,
 
   vc <- stats::vcov(x)
 
-  if (.is_negativ_matrix(vc)) {
+  if (.is_negativ_matrix(vc, ...)) {
     vc <- .fix_negative_matrix(vc)
   }
 
@@ -156,7 +221,9 @@ get_varcov.clmm2 <- get_varcov.clm2
 #' @export
 get_varcov.glmx <- function(x,
                             component = c("all", "conditional", "extra"),
+                            verbose = TRUE,
                             ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
   vc <- stats::vcov(object = x)
 
@@ -164,12 +231,13 @@ get_varcov.glmx <- function(x,
     keep <- match(find_parameters(x)[[component]], rownames(vc))
     vc <- vc[keep, keep, drop = FALSE]
   }
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
-get_varcov.pgmm <- function(x, component = c("conditional", "all"), ...) {
+get_varcov.pgmm <- function(x, component = c("conditional", "all"), verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
   vc <- stats::vcov(x)
 
@@ -177,7 +245,7 @@ get_varcov.pgmm <- function(x, component = c("conditional", "all"), ...) {
     keep <- match(find_parameters(x)[[component]], rownames(vc))
     vc <- vc[keep, keep, drop = FALSE]
   }
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
@@ -185,6 +253,7 @@ get_varcov.pgmm <- function(x, component = c("conditional", "all"), ...) {
 get_varcov.selection <- function(x,
                                  component = c("all", "selection", "outcome", "auxiliary"),
                                  ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
   vc <- stats::vcov(object = x)
 
@@ -194,7 +263,7 @@ get_varcov.selection <- function(x,
   }
 
   # we can't check for rank-deficiency here...
-  if (.is_negativ_matrix(vc)) {
+  if (.is_negativ_matrix(vc, ...)) {
     vc <- .fix_negative_matrix(vc)
   }
   text_remove_backticks(as.matrix(vc))
@@ -204,7 +273,9 @@ get_varcov.selection <- function(x,
 #' @export
 get_varcov.mvord <- function(x,
                              component = c("all", "conditional", "thresholds", "correlation"),
+                             verbose = TRUE,
                              ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
   vc <- stats::vcov(x)
 
@@ -216,25 +287,31 @@ get_varcov.mvord <- function(x,
     keep <- match(fp, rownames(vc))
     vc <- vc[keep, keep, drop = FALSE]
   }
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
 get_varcov.mjoint <- function(x,
                               component = c("all", "conditional", "survival"),
+                              verbose = TRUE,
                               ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
   vc <- stats::vcov(x)
 
   keep <- match(find_parameters(x, flatten = TRUE, component = component), rownames(vc))
   vc <- vc[keep, keep, drop = FALSE]
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
-get_varcov.mhurdle <- function(x, component = c("all", "conditional", "zi", "zero_inflated", "infrequent_purchase", "ip", "auxiliary"), ...) {
+get_varcov.mhurdle <- function(x,
+                               component = c("all", "conditional", "zi", "zero_inflated", "infrequent_purchase", "ip", "auxiliary"),
+                               verbose = TRUE,
+                               ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
   vc <- stats::vcov(x)
 
@@ -243,26 +320,27 @@ get_varcov.mhurdle <- function(x, component = c("all", "conditional", "zi", "zer
 
   keep <- match(find_parameters(x, flatten = TRUE, component = component), rownames(vc))
   vc <- vc[keep, keep, drop = FALSE]
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @rdname get_varcov
 #' @export
-get_varcov.truncreg <- function(x, component = c("conditional", "all"), ...) {
+get_varcov.truncreg <- function(x, component = c("conditional", "all"), verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
   vc <- stats::vcov(x)
 
   if (component == "conditional") {
     vc <- vc[1:(nrow(vc) - 1), 1:(ncol(vc) - 1), drop = FALSE]
   }
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
-#' @rdname get_varcov
 #' @export
-get_varcov.gamlss <- function(x, component = c("conditional", "all"), ...) {
+get_varcov.gamlss <- function(x, component = c("conditional", "all"), verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
   vc <- suppressWarnings(stats::vcov(x))
 
@@ -270,7 +348,7 @@ get_varcov.gamlss <- function(x, component = c("conditional", "all"), ...) {
     cond_pars <- length(find_parameters(x)$conditional)
     vc <- as.matrix(vc)[1:cond_pars, 1:cond_pars, drop = FALSE]
   }
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
@@ -285,16 +363,39 @@ get_varcov.gamlss <- function(x, component = c("conditional", "all"), ...) {
 #' @export
 get_varcov.hurdle <- function(x,
                               component = c("conditional", "zero_inflated", "zi", "all"),
+                              vcov = NULL,
+                              vcov_args = NULL,
+                              verbose = TRUE,
                               ...) {
+  .check_get_varcov_dots(x, ...)
+  # process vcov-argument
+  vcov <- .check_vcov_args(x, vcov = vcov, verbose = verbose, ...)
+
   component <- match.arg(component)
 
-  vc <- switch(component,
-    "conditional" = stats::vcov(object = x, model = "count"),
-    "zi" = ,
-    "zero_inflated" = stats::vcov(object = x, model = "zero"),
-    stats::vcov(object = x)
-  )
-  .process_vcov(vc)
+  if (is.null(vcov)) {
+    vc <- switch(component,
+      "conditional" = stats::vcov(object = x, model = "count"),
+      "zi" = ,
+      "zero_inflated" = stats::vcov(object = x, model = "zero"),
+      stats::vcov(object = x)
+    )
+  } else {
+    vc <- .get_varcov_sandwich(x,
+                               vcov_fun = vcov,
+                               vcov_args = vcov_args,
+                               verbose = verbose,
+                               ...)
+    keep <- switch(component,
+      "conditional" = grepl("^count_", colnames(vc)),
+      "zi" = ,
+      "zero_inflated" = grepl("^zero_", colnames(vc)),
+      1:ncol(vc)
+    )
+    vc <- vc[keep, keep, drop = FALSE]
+  }
+
+  .process_vcov(vc, verbose, ...)
 }
 
 #' @export
@@ -303,11 +404,12 @@ get_varcov.zeroinfl <- get_varcov.hurdle
 #' @export
 get_varcov.zerocount <- get_varcov.hurdle
 
-#' @rdname get_varcov
 #' @export
 get_varcov.zcpglm <- function(x,
                               component = c("conditional", "zero_inflated", "zi", "all"),
+                              verbose = TRUE,
                               ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
 
   # installed?
@@ -323,7 +425,7 @@ get_varcov.zcpglm <- function(x,
     "zero_inflated" = vc[zero, zero, drop = FALSE],
     vc[c(tweedie, zero), c(tweedie, zero), drop = FALSE]
   )
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
@@ -335,7 +437,9 @@ get_varcov.zcpglm <- function(x,
 #' @export
 get_varcov.glmmTMB <- function(x,
                                component = c("conditional", "zero_inflated", "zi", "dispersion", "all"),
+                               verbose = TRUE,
                                ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
 
   vc <- switch(component,
@@ -345,7 +449,7 @@ get_varcov.glmmTMB <- function(x,
     "dispersion" = stats::vcov(x)[["disp"]],
     stats::vcov(x, full = TRUE)
   )
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
@@ -354,9 +458,15 @@ get_varcov.glmmTMB <- function(x,
 get_varcov.MixMod <- function(x,
                               effects = c("fixed", "random"),
                               component = c("conditional", "zero_inflated", "zi", "dispersion", "auxiliary", "all"),
-                              robust = FALSE,
                               verbose = TRUE,
                               ...) {
+  .check_get_varcov_dots(x, ...)
+
+  # backward compatibility. there used to be a `robust` argument in this
+  # method, but we have now moved to `vcov` and `vcov_args`. Also, `robust`
+  # does not seem to be a documented argument for the `MixMod` class.
+  robust <- isTRUE(list(...)[["robust"]])
+
   component <- match.arg(component)
   effects <- match.arg(effects)
 
@@ -387,7 +497,7 @@ get_varcov.MixMod <- function(x,
     }
   }
 
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
@@ -398,13 +508,14 @@ get_varcov.MixMod <- function(x,
 
 #' @rdname get_varcov
 #' @export
-get_varcov.brmsfit <- function(x, component = "conditional", ...) {
+get_varcov.brmsfit <- function(x, component = "conditional", verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component, choices = c("all", .all_elements()))
   params <- find_parameters(x, effects = "fixed", component = component, flatten = TRUE)
   params <- gsub("^b_", "", params)
 
   vc <- stats::vcov(x)[params, params, drop = FALSE]
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
@@ -415,17 +526,20 @@ get_varcov.brmsfit <- function(x, component = "conditional", ...) {
 #' @export
 get_varcov.betamfx <- function(x,
                                component = c("conditional", "precision", "all"),
+                               verbose = TRUE,
                                ...) {
+  .check_get_varcov_dots(x, ...)
   component <- match.arg(component)
-  get_varcov.betareg(x$fit, component = component, ...)
+  get_varcov.betareg(x$fit, component = component, verbose = verbose, ...)
 }
 
 #' @export
 get_varcov.betaor <- get_varcov.betamfx
 
 #' @export
-get_varcov.logitmfx <- function(x, ...) {
-  get_varcov(x$fit, ...)
+get_varcov.logitmfx <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
+  get_varcov(x$fit, verbose = verbose, ...)
 }
 
 #' @export
@@ -455,6 +569,7 @@ get_varcov.model_fit <- get_varcov.logitmfx
 
 #' @export
 get_varcov.merModList <- function(x, ...) {
+  .check_get_varcov_dots(x, ...)
   warning("Can't access variance-covariance matrix for 'merModList' objects.", call. = FALSE)
   return(NULL)
 }
@@ -462,6 +577,7 @@ get_varcov.merModList <- function(x, ...) {
 
 #' @export
 get_varcov.mediate <- function(x, ...) {
+  .check_get_varcov_dots(x, ...)
   warning("Can't access variance-covariance matrix for 'mediate' objects.", call. = FALSE)
   return(NULL)
 }
@@ -469,50 +585,68 @@ get_varcov.mediate <- function(x, ...) {
 
 #' @rdname get_varcov
 #' @export
-get_varcov.aov <- function(x, complete = FALSE, ...) {
+get_varcov.aov <- function(x, complete = FALSE, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- suppressWarnings(stats::vcov(x, complete = complete))
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
-get_varcov.ivFixed <- function(x, ...) {
-  .process_vcov(x$vcov)
+get_varcov.ivFixed <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
+  .process_vcov(x$vcov, verbose = verbose, ...)
 }
 
 
 #' @export
-get_varcov.averaging <- function(x, ...) {
+get_varcov.averaging <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   if (is.null(attributes(x)$modelList)) {
     warning("Can't calculate covariance matrix. Please use 'fit = TRUE' in 'model.avg()'.", call. = FALSE)
   } else {
-    get_varcov.default(x)
+    get_varcov.default(x, verbose = verbose, ...)
   }
 }
 
 
 #' @export
-get_varcov.robmixglm <- function(x, ...) {
+get_varcov.robmixglm <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   params <- find_parameters(x, flatten = TRUE)
   np <- length(params)
   vc <- x$fit@vcov[1:np, 1:np, drop = FALSE]
 
   dimnames(vc) <- list(params, params)
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
-get_varcov.Rchoice <- function(x, ...) {
+get_varcov.bife <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
+  params <- find_parameters(x, flatten = TRUE)
+  np <- length(params)
+  vc <- stats::vcov(x)[1:np, 1:np, drop = FALSE]
+
+  dimnames(vc) <- list(params, params)
+  .process_vcov(vc, verbose, ...)
+}
+
+
+#' @export
+get_varcov.Rchoice <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- stats::vcov(x)
   params <- find_parameters(x, flatten = TRUE)
   dimnames(vc) <- list(params, params)
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
 get_varcov.rq <- function(x, ...) {
+  .check_get_varcov_dots(x, ...)
   s <- summary(x, covariance = TRUE)
   vc <- as.matrix(s$cov)
 
@@ -521,7 +655,7 @@ get_varcov.rq <- function(x, ...) {
   rownames(vc) <- preds
   colnames(vc) <- preds
 
-  if (.is_negativ_matrix(vc)) {
+  if (.is_negativ_matrix(vc, ...)) {
     vc <- .fix_negative_matrix(vc)
   }
 
@@ -530,16 +664,18 @@ get_varcov.rq <- function(x, ...) {
 
 
 #' @export
-get_varcov.crr <- function(x, ...) {
+get_varcov.crr <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- as.matrix(x$var)
   params <- find_parameters(x, flatten = TRUE)
   dimnames(vc) <- list(params, params)
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
 get_varcov.crq <- function(x, ...) {
+  .check_get_varcov_dots(x, ...)
   sc <- summary(x, covariance = TRUE)
   preds <- find_parameters(x, flatten = TRUE)
 
@@ -551,7 +687,7 @@ get_varcov.crq <- function(x, ...) {
       rownames(.x) <- preds
       colnames(.x) <- preds
 
-      if (.is_negativ_matrix(.x)) {
+      if (.is_negativ_matrix(.x, ...)) {
         .x <- .fix_negative_matrix(.x)
       }
       .x
@@ -559,7 +695,7 @@ get_varcov.crq <- function(x, ...) {
     names(vc) <- sprintf("tau (%g)", unlist(lapply(sc, function(i) i$tau)))
   } else {
     vc <- as.matrix(sc$cov)
-    if (.is_negativ_matrix(vc)) {
+    if (.is_negativ_matrix(vc, ...)) {
       vc <- .fix_negative_matrix(vc)
     }
     vc <- text_remove_backticks(as.matrix(vc))
@@ -576,30 +712,34 @@ get_varcov.rqs <- get_varcov.crq
 
 
 #' @export
-get_varcov.flexsurvreg <- function(x, ...) {
+get_varcov.flexsurvreg <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   pars <- find_parameters(x, flatten = TRUE)
   vc <- as.matrix(stats::vcov(x))[pars, pars, drop = FALSE]
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
-get_varcov.afex_aov <- function(x, ...) {
-  get_varcov(x$lm, ...)
+get_varcov.afex_aov <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
+  get_varcov(x$lm, verbose = verbose, ...)
 }
 
 
 #' @export
-get_varcov.mixed <- function(x, ...) {
+get_varcov.mixed <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- as.matrix(stats::vcov(x$full_model))
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
-get_varcov.cpglmm <- function(x, ...) {
+get_varcov.cpglmm <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- as.matrix(x@vcov)
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 #' @export
@@ -608,17 +748,19 @@ get_varcov.cpglm <- get_varcov.cpglmm
 
 
 #' @export
-get_varcov.cglm <- function(x, ...) {
+get_varcov.cglm <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- as.matrix(x$var)
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 
 #' @export
-get_varcov.mle2 <- function(x, ...) {
+get_varcov.mle2 <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- as.matrix(x@vcov)
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
@@ -629,11 +771,12 @@ get_varcov.mle <- get_varcov.mle2
 
 #' @rdname get_varcov
 #' @export
-get_varcov.mixor <- function(x, effects = c("all", "fixed", "random"), ...) {
+get_varcov.mixor <- function(x, effects = c("all", "fixed", "random"), verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   effects <- match.arg(effects)
   params <- find_parameters(x, effects = effects, flatten = TRUE)
   vc <- as.matrix(stats::vcov(x))[params, params, drop = FALSE]
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
@@ -642,21 +785,23 @@ get_varcov.glmm <- get_varcov.mixor
 
 
 #' @export
-get_varcov.gamm <- function(x, ...) {
+get_varcov.gamm <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- stats::vcov(x$gam)
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
 get_varcov.lqmm <- function(x, ...) {
+  .check_get_varcov_dots(x, ...)
   sc <- summary(x, covariance = TRUE)
   np <- length(find_parameters(x, flatten = TRUE))
 
   if (length(dim(sc$Cov)) == 3) {
     vc <- lapply(1:length(x$tau), function(i) {
       .x <- sc$Cov[, , i][1:np, 1:np]
-      if (.is_negativ_matrix(.x)) {
+      if (.is_negativ_matrix(.x, ...)) {
         .x <- .fix_negative_matrix(.x)
       }
       .x
@@ -664,7 +809,7 @@ get_varcov.lqmm <- function(x, ...) {
     names(vc) <- sprintf("tau (%g)", x$tau)
   } else {
     vc <- as.matrix(sc$Cov)[1:np, 1:np]
-    if (.is_negativ_matrix(vc)) {
+    if (.is_negativ_matrix(vc, ...)) {
       vc <- .fix_negative_matrix(vc)
     }
     vc <- text_remove_backticks(as.matrix(vc))
@@ -678,52 +823,57 @@ get_varcov.lqm <- get_varcov.lqmm
 
 
 #' @export
-get_varcov.list <- function(x, ...) {
+get_varcov.list <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   if ("gam" %in% names(x)) {
     vc <- stats::vcov(x$gam)
-    .process_vcov(vc)
+    .process_vcov(vc, verbose, ...)
   }
 }
 
 
 #' @export
-get_varcov.BBmm <- function(x, ...) {
+get_varcov.BBmm <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- x$fixed.vcov
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
-get_varcov.BBreg <- function(x, ...) {
+get_varcov.BBreg <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- x$vcov
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
-get_varcov.feis <- function(x, ...) {
+get_varcov.feis <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- x$vcov
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
-get_varcov.glimML <- function(x, ...) {
+get_varcov.glimML <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   # installed?
   check_if_installed("aod")
 
   vc <- aod::vcov(x)
-
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
-get_varcov.vglm <- function(x, ...) {
+get_varcov.vglm <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   # installed?
   check_if_installed("VGAM")
   vc <- VGAM::vcov(x)
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
@@ -732,24 +882,19 @@ get_varcov.vgam <- get_varcov.vglm
 
 
 #' @export
-get_varcov.geeglm <- function(x, ...) {
-  vc <- summary(x)$cov.unscaled
-  .process_vcov(vc)
-}
-
-
-#' @export
-get_varcov.tobit <- function(x, ...) {
+get_varcov.tobit <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   coef_names <- find_parameters(x, flatten = TRUE)
   vc <- stats::vcov(x)[coef_names, coef_names, drop = FALSE]
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
-get_varcov.lmRob <- function(x, ...) {
+get_varcov.lmRob <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- x$cov
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
@@ -759,16 +904,18 @@ get_varcov.glmRob <- get_varcov.lmRob
 
 
 #' @export
-get_varcov.coxr <- function(x, ...) {
+get_varcov.coxr <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- x$var
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
 #' @export
-get_varcov.gee <- function(x, ...) {
+get_varcov.gee <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
   vc <- x$naive.variance
-  .process_vcov(vc)
+  .process_vcov(vc, verbose, ...)
 }
 
 
@@ -780,8 +927,8 @@ get_varcov.LORgee <- get_varcov.gee
 # helper-functions -----------------------------------------------------
 
 
-.process_vcov <- function(vc, verbose = TRUE) {
-  if (.is_negativ_matrix(vc)) {
+.process_vcov <- function(vc, verbose = TRUE, ...) {
+  if (.is_negativ_matrix(vc, ...)) {
     vc <- .fix_negative_matrix(vc)
   }
   # fix possible missings due to rank deficient model matrix
@@ -790,13 +937,17 @@ get_varcov.LORgee <- get_varcov.gee
 }
 
 
-.is_negativ_matrix <- function(x) {
+.is_negativ_matrix <- function(x, pd_tolerance = 1e-08, ...) {
+  # allow "NULL" to skip this test
+  if (is.null(pd_tolerance)) {
+    return(FALSE)
+  }
   if (is.matrix(x) && (nrow(x) == ncol(x))) {
     rv <- tryCatch(
       {
         eigenvalues <- eigen(x, only.values = TRUE)$values
-        eigenvalues[abs(eigenvalues) < 1e-07] <- 0
-        any(eigenvalues <= 0)
+        eigenvalues[abs(eigenvalues) < pd_tolerance] <- 0
+        any(eigenvalues < 0)
       },
       error = function(e) {
         FALSE
@@ -812,6 +963,8 @@ get_varcov.LORgee <- get_varcov.gee
 
 .fix_negative_matrix <- function(m) {
   if (requireNamespace("Matrix", quietly = TRUE)) {
+    message(format_message("The variance-covariance matrix is not positive definite. Returning the nearest positive definite matrix now.",
+                           "This ensures that eigenvalues are all positive real numbers, and thereby, for instance, it is possible to calculate standard errors for all relevant parameters."))
     as.matrix(Matrix::nearPD(m)$mat)
   } else {
     m
@@ -874,3 +1027,38 @@ get_varcov.LORgee <- get_varcov.gee
     }
   }
 }
+
+.check_get_varcov_dots <- function(x, ...) {
+  dots <- list(...)
+  # if `vcov` is in ..., it means that the argument is not
+  # explicitly supported by a method, and thus that it will
+  # not be passed here through ... and will not trigger a
+  # warning here.
+  if ("vcov" %in% names(dots) && !is.null(dots[["vcov"]])) {
+    msg <- sprintf("The `vcov` argument of the `insight::get_varcov()` function is not yet supported for models of class `%s`.", paste(class(x), collapse = "/"))
+    warning(format_message(msg), call. = FALSE)
+  }
+}
+
+
+.check_vcov_args <- function(x, vcov, verbose = TRUE, ...) {
+  dots <- list(...)
+
+  # backward compatibility for `get_predicted_se()`
+  if (is.null(vcov) && "vcov_estimation" %in% names(dots)) {
+    vcov <- dots[["vcov_estimation"]]
+  }
+
+  if ("robust" %in% names(dots)) {
+    # default robust covariance
+    if (is.null(vcov)) {
+      vcov <- "HC3"
+    }
+    if (isTRUE(verbose)) {
+      warning("The `robust` argument is deprecated. Please use `vcov` instead.",
+              call. = FALSE)
+    }
+  }
+
+  vcov
+}
