@@ -1,14 +1,14 @@
 #' @title Compute intercept-only model for regression models
 #' @name null_model
 #'
-#' @description This function computes the null-model (i.e. \code{(y ~ 1)}) of
+#' @description This function computes the null-model (i.e. `(y ~ 1)`) of
 #'   a model. For mixed models, the null-model takes random effects into account.
 #'
 #' @param model A (mixed effects) model.
 #' @param verbose Toggle off warnings.
 #' @param ... Arguments passed to or from other methods.
 #'
-#' @return The null-model of \code{x}
+#' @return The null-model of `x`
 #'
 #' @examples
 #' if (require("lme4")) {
@@ -41,7 +41,7 @@ null_model <- function(model, verbose = TRUE, ...) {
   } else {
     f <- stats::formula(model)
     resp <- find_response(model)
-    re.terms <- paste0("(", sapply(.findbars(f), .safe_deparse), ")")
+    re.terms <- paste0("(", sapply(.findbars(f), safe_deparse), ")")
     nullform <- stats::reformulate(re.terms, response = resp)
     null.model <- tryCatch(
       {
