@@ -25,6 +25,10 @@ if (requiet("testthat") &&
     data = sleepstudy
   )
 
+  # from easystats/insight/482
+  cr <- corAR1(form = ~ 1 | Mare)
+  m4 <- lme(follicles ~ Time, Ovary, correlation = cr)
+
   test_that("nested_varCorr", {
     skip_on_cran()
 
@@ -81,7 +85,7 @@ if (requiet("testthat") &&
   })
 
   test_that("get_random", {
-    expect_equal(get_random(m1), data.frame(Subject = sleepstudy$Subject))
+    expect_equal(get_random(m1), data.frame(Subject = sleepstudy$Subject), ignore_attr = TRUE)
     expect_warning(get_random(m2))
   })
 
@@ -114,6 +118,15 @@ if (requiet("testthat") &&
       ),
       ignore_attr = TRUE
     )
+    expect_length(find_formula(m4), 2)
+    expect_equal(
+      find_formula(m4),
+      list(
+        conditional = as.formula("follicles ~ Time"),
+        correlation = as.formula("~1 | Mare")
+      ),
+      ignore_attr = TRUE
+    )
   })
 
   test_that("find_variables", {
